==> vb-react-form-0.0.4.tgz: package/es/form-field-errors.js <==
import _extends from 'babel-runtime/helpers/extends';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import React from 'react';
import { FormContext } from './form-context';

var FormFieldErrorsComponent = function (_React$Component) {
  _inherits(FormFieldErrorsComponent, _React$Component);

  function FormFieldErrorsComponent() {
    _classCallCheck(this, FormFieldErrorsComponent);

    return _possibleConstructorReturn(this, _React$Component.apply(this, arguments));
  }

  FormFieldErrorsComponent.prototype.render = function render() {
    var _props = this.props,
        field = _props.field,
        formError = _props.formError,
        other = _objectWithoutProperties(_props, ['field', 'formError']);

    return field.dirty ? React.createElement(
      'div',
      other,
      field.errors.map(function (error, index) {
        return React.createElement(
          'div',
          { key: index },
          error
        );
      }),
      field.asyncErrors.map(function (error, index) {
        return React.createElement(
          'div',
          { key: index },
          error
        );
      }),
      formError
    ) : null;
  };

  return FormFieldErrorsComponent;
}(React.Component);

var FormFieldErrors = function (_React$Component2) {
  _inherits(FormFieldErrors, _React$Component2);

  function FormFieldErrors(props, context) {
    _classCallCheck(this, FormFieldErrors);

    var _this2 = _possibleConstructorReturn(this, _React$Component2.call(this, props, context));

    _this2.formError = false;
    return _this2;
  }

  FormFieldErrors.prototype.componentDidMount = function componentDidMount() {
    var _this3 = this;

    this.fieldSubscriberId = this.context.form.fields.subscribe(function () {
      _this3.forceUpdate();
    }, this.props.name);
    this.formFieldSubscriberId = this.context.form.validators.subscribe(function (error) {
      if (_this3.formError !== error) {
        _this3.formError = error;
        _this3.forceUpdate();
      }
    }, this.props.name);
  };

  FormFieldErrors.prototype.componentWillUnmount = function componentWillUnmount() {
    this.context.form.fields.removeSubscriber(this.fieldSubscriberId);
    this.context.form.validators.removeSubscriber(this.formFieldSubscriberId);
    this.fieldSubscriberId = null;
    this.formFieldSubscriberId = null;
  };

  FormFieldErrors.prototype.render = function render() {
    var _props2 = this.props,
        name = _props2.name,
        component = _props2.component,
        other = _objectWithoutProperties(_props2, ['name', 'component']);

    var field = this.context.form.fields.getFieldOptions(name);
    var element = React.createElement(component || FormFieldErrorsComponent, _extends({
      field: field,
      formError: this.formError
    }, other));
    return field ? element : null;
  };

  return FormFieldErrors;
}(React.Component);

FormFieldErrors.propTypes = {
  name: React.PropTypes.string.isRequired,
  component: React.PropTypes.func
};

FormFieldErrors.contextTypes = {
  form: React.PropTypes.instanceOf(FormContext).isRequired
};

export { FormFieldErrors };

==> vb-react-form-0.0.8.tgz: package/es/form-field-errors.js <==
import _extends from 'babel-runtime/helpers/extends';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import React from 'react';
import PropTypes from 'prop-types';
import { FormContext } from './form-context';

var FormFieldErrorsComponent = function (_React$Component) {
  _inherits(FormFieldErrorsComponent, _React$Component);

  function FormFieldErrorsComponent() {
    _classCallCheck(this, FormFieldErrorsComponent);

    return _possibleConstructorReturn(this, _React$Component.apply(this, arguments));
  }

  FormFieldErrorsComponent.prototype.render = function render() {
    var _props = this.props,
        field = _props.field,
        formError = _props.formError,
        other = _objectWithoutProperties(_props, ['field', 'formError']);

    return field.dirty ? React.createElement(
      'div',
      other,
      field.errors.map(function (error, index) {
        return React.createElement(
          'div',
          { key: index },
          error
        );
      }),
      field.asyncErrors.map(function (error, index) {
        return React.createElement(
          'div',
          { key: index },
          error
        );
      }),
      formError
    ) : null;
  };

  return FormFieldErrorsComponent;
}(React.Component);

var FormFieldErrors = function (_React$Component2) {
  _inherits(FormFieldErrors, _React$Component2);

  function FormFieldErrors(props, context) {
    _classCallCheck(this, FormFieldErrors);

    var _this2 = _possibleConstructorReturn(this, _React$Component2.call(this, props, context));

    _this2.formError = false;
    return _this2;
  }

  FormFieldErrors.prototype.componentDidMount = function componentDidMount() {
    var _this3 = this;

    this.fieldSubscriberId = this.context.form.fields.subscribe(function () {
      _this3.forceUpdate();
    }, this.props.name);
    this.formFieldSubscriberId = this.context.form.validators.subscribe(function (error) {
      if (_this3.formError !== error) {
        _this3.formError = error;
        _this3.forceUpdate();
      }
    }, this.props.name);
  };

  FormFieldErrors.prototype.componentWillUnmount = function componentWillUnmount() {
    this.context.form.fields.removeSubscriber(this.fieldSubscriberId);
    this.context.form.validators.removeSubscriber(this.formFieldSubscriberId);
    this.fieldSubscriberId = null;
    this.formFieldSubscriberId = null;
  };

  FormFieldErrors.prototype.render = function render() {
    var _props2 = this.props,
        name = _props2.name,
        component = _props2.component,
        other = _objectWithoutProperties(_props2, ['name', 'component']);

    var field = this.context.form.fields.getFieldOptions(name);
    var element = React.createElement(component || FormFieldErrorsComponent, _extends({
      field: field,
      formError: this.formError
    }, other));
    return field ? element : null;
  };

  return FormFieldErrors;
}(React.Component);

FormFieldErrors.propTypes = {
  name: PropTypes.string.isRequired,
  component: PropTypes.func
};

FormFieldErrors.contextTypes = {
  form: PropTypes.instanceOf(FormContext).isRequired
};

export { FormFieldErrors };
